==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicBorders.h <==
// public class javax.swing.plaf.basic.BasicBorders

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 10f2ad02031aa6f9 javax_swing_plaf_basic_BasicBorders

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders_H_
#define _JC_javax_swing_plaf_basic_BasicBorders_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$refs	_jc_javax_swing_plaf_basic_BasicBorders$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$object	_jc_javax_swing_plaf_basic_BasicBorders$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders$vmethods	_jc_javax_swing_plaf_basic_BasicBorders$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders$vtable	_jc_javax_swing_plaf_basic_BasicBorders$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders$vtype	_jc_javax_swing_plaf_basic_BasicBorders$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders$fields_struct {
	struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object	*sharedMarginBorder;
};
extern _jc_javax_swing_plaf_basic_BasicBorders$fields_struct _jc_javax_swing_plaf_basic_BasicBorders$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders$object *);

// Static methods
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getButtonBorder$0c1a351a7931617a(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getInternalFrameBorder$c9547cd7b17408fd(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getMarginBorder$403ded691bf659a5(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getMenuBarBorder$767d7d03d5421871(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getProgressBarBorder$b2e93e61d3f077b6(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getRadioButtonBorder$28cc1e096fbb1d2f(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getSplitPaneBorder$ccecb9efd8e4b3ed(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getSplitPaneDividerBorder$1fb0035488d8f8d8(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getTextFieldBorder$21a69a4782d7fd03(_jc_env *);
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getToggleButtonBorder$6846237265ac024d(_jc_env *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicBorders$vmethods	javax_swing_plaf_basic_BasicBorders;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders$refs {
    _jc_javax_swing_plaf_basic_BasicBorders$sub_refs	javax_swing_plaf_basic_BasicBorders;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs	javax_swing_plaf_basic_BasicBorders;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders$object {
	_jc_javax_swing_plaf_basic_BasicBorders$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders$vtype _jc_javax_swing_plaf_basic_BasicBorders$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicBorders.h <==
// public class javax.swing.plaf.basic.BasicBorders

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 10f2ad02031aa6f9 javax_swing_plaf_basic_BasicBorders

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders_H_
#define _JC_javax_swing_plaf_basic_BasicBorders_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_border_Border$object;
struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$refs	_jc_javax_swing_plaf_basic_BasicBorders$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders$object	_jc_javax_swing_plaf_basic_BasicBorders$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders$vmethods	_jc_javax_swing_plaf_basic_BasicBorders$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders$vtable	_jc_javax_swing_plaf_basic_BasicBorders$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders$vtype	_jc_javax_swing_plaf_basic_BasicBorders$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders$fields_struct {
	struct _jc_javax_swing_plaf_basic_BasicBorders__24MarginBorder$object	*sharedMarginBorder;
};
extern _jc_javax_swing_plaf_basic_BasicBorders$fields_struct _jc_javax_swing_plaf_basic_BasicBorders$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getButtonBorder$0c1a351a7931617a(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getInternalFrameBorder$c9547cd7b17408fd(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getMarginBorder$403ded691bf659a5(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getMenuBarBorder$767d7d03d5421871(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getProgressBarBorder$b2e93e61d3f077b6(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getRadioButtonBorder$28cc1e096fbb1d2f(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getSplitPaneBorder$ccecb9efd8e4b3ed(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getSplitPaneDividerBorder$1fb0035488d8f8d8(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getTextFieldBorder$21a69a4782d7fd03(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicBorders$method$getToggleButtonBorder$6846237265ac024d(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicBorders$vmethods	javax_swing_plaf_basic_BasicBorders;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders$refs {
    _jc_javax_swing_plaf_basic_BasicBorders$sub_refs	javax_swing_plaf_basic_BasicBorders;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicBorders$sub_nonrefs	javax_swing_plaf_basic_BasicBorders;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders$object {
	_jc_javax_swing_plaf_basic_BasicBorders$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders$vtype _jc_javax_swing_plaf_basic_BasicBorders$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders_H_ */
